
# Slot: singleton_activities

The set of activities that have no causal associations, i.e. those that are not connected to any other activity in the model.

URI: [gocam:queryIndex__singleton_activities](https://w3id.org/gocam/queryIndex__singleton_activities)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [Activity](Activity.md)

## Parents


## Children


## Used by

 * [QueryIndex](QueryIndex.md)
